## Zip contents

The files in this zip are as follows:

- **README.md**: this file

- **package.json**: defines the "start" command which launches a minimal local http server to serve the contents
  of uux-sca/ sub-directory (see below)

  NB: This is necessary because browsers disallow js **fetch()** calls from javascript contained in html pages loaded
  from the file-system (vs. from a URL).

- **uux-sca/**:
  - **index.html**: contains links to the two example pages for (a) local and (b) third-party SCA

  - **uux-sca-min.js**: the UUX SCA library (defining classes: SCAConfigDigest and SCAManager) to coordinate the sequence
    of API calls necessary to perform either (a) "direct" authentication by a local/bespoke login page, or
    (b) "indirect" authentication via a third-party login page

  - **local/**:
    - **config.js**: defines config properties for ./index.html (below)

    - **index.html**: an example htmp page that presents a login form and uses SCAConfigDigest/SCAManager library classes
      to manage authentication of credentials submitted via that form via a "direct" authentication process

  - **third-party/**:
    - **config.js**: defines config properties for ./index.html (below)

    - **index.html**: an example page that presents an "Authenticate" button and uses SCAConfigDigest/SCAManager library
      classes to manage "indirect" authentication via a third-party login page / authentication process when that button
      is clicked.

## Prerequisites

The instructions below assume that you have NPM and Yarn installed on your machine. If you don't (or are unsure) please
follow the instructions [here](https://developer.temenos.com/uux/docs/develop/getting-started/installation) to check (and,
if necessary, install).

## Installation

- create a directory on your filesystem and unpack the contents of this zip file into it

- open a command-prompt on that directory

- invoke the following command to start a minimal http server to serve the contents of the uux-sca/ sub-directory:

  ```
  yarn start
  ```

  This will install the necessary packages and run up the http server, showing output indicating that content is
  now being served at address: http://localhost:3001

- open http://localhost:3001 in your browser: you should see a landing page providing links to the 2 demo pages
  (these links will open new windows when clicked)

## Testing the Direct SCA via local/bespoke login page (http://localhost:3001/local/)

- open your browser's developer tools so that you can monitor messages logged to the console

- valid credentials for this local/bespoke login page are:
  - Username: INPUTTER
  - Password: 123456

- on clicking the "Authenticate" button (which is only enabled once both fields are filled) - or equivalently,
  pressing the Enter key in the Password field - you should see:

  - the screen is briefly disabled (all controls being hidden behind a glasspane with a "Processing, please wait..."
    message box)

  - if you supplied valid credentials above, you should see:
    - that the "Processing, please wait..." message is cleared, but the glasspane is still in place
    - the JWT obtained from the SCA services is reported in an alert box
    - on dismissing the alert box, the Username and Password fields are cleared, the glasspane is removed
      and the Username field is refocussed ready for another login attempt

  - otherwise (i.e. you supplied invalid credentials), you should see:
    - that the "Processing, please wait..." message is cleared, but the glasspane is still in place
    - the message: "Invalid username or password" is reported in an alert box
    - on dismissal of the alert box the glasspane is removed (Username and Password field contents being
      left intact) and the Username field is refocussed ready for another attempt

## Testing Indirect SCA via third-party login page (http://localhost:3001/third-party/)

- open your browser's developer tools so that you can monitor messages logged to the console

- now click the "Authenticate" button: this should cause a login page to open in a new window/tab

- if you switch back to the Indirect SCA page at this point, you should see (a) some messages appearing in the console,
  and (b) that the page itself is now disabled by a glasspane (to prevent the user performing any other actions on
  that page until the authentication process has completed / timed out / failed).

- valid credentials for the third-party login page opened on clicking the "Authenticate" button are as follows:

  - Username: user10000
  - Password: Password01

- providing you submit valid credentials within approximately 30 seconds (see properties: delaySecsBeforeFirstGetJwtAttempt,
  maxGetJWTAttempts and getJWTRetryIntervalSecs in uux-sca/config.js), the UUX SCA page should shortly thereafter report the JWT
  otained from the SCA authentication services in an alert (automatically closing the login page).

- if you fail to submit valid credentials within that period, the UUX SCA page should report a timeout via an alert (again
  automatically closing the third-party login page).

- on dismissal of the applicable alert message, the glasspane should be removed (so renabling the page for another attempt)
